@@ -21,6 +21,7 @@ Rcpp::List mmd_gau_Rcpp(Rcpp::NumericVector X,
                         Rcpp::IntegerVector dY_,
                         Rcpp::NumericVector beta_);
 
+
 Rcpp::List mmd_lap_pval_Rcpp(Rcpp::NumericVector X, 
                              Rcpp::NumericVector Y, 
                              Rcpp::IntegerVector nX_, 
@@ -29,7 +30,10 @@ Rcpp::List mmd_lap_pval_Rcpp(Rcpp::NumericVector X,
                              Rcpp::IntegerVector dY_,
                              Rcpp::IntegerVector numperm_,
                              Rcpp::IntegerVector seednum_,
-                             Rcpp::NumericVector beta_);
+                             Rcpp::NumericVector beta_, 
+                             Rcpp::IntegerVector twosided_,
+                             Rcpp::IntegerVector boundedminpval_);
+
 
 Rcpp::List mmd_gau_pval_Rcpp(Rcpp::NumericVector X, 
                              Rcpp::NumericVector Y, 
@@ -39,7 +43,9 @@ Rcpp::List mmd_gau_pval_Rcpp(Rcpp::NumericVector X,
                              Rcpp::IntegerVector dY_,
                              Rcpp::IntegerVector numperm_,
                              Rcpp::IntegerVector seednum_,
-                             Rcpp::NumericVector beta_);
+                             Rcpp::NumericVector beta_,
+                             Rcpp::IntegerVector twosided_, 
+                             Rcpp::IntegerVector boundedminpval_);
 
 
 Rcpp::NumericVector fast_median_diff_Rcpp(Rcpp::NumericVector X_);
@@ -60,7 +66,9 @@ Rcpp::List eummd_pval_Rcpp(Rcpp::NumericVector X_,
                            Rcpp::NumericVector Y_, 
                            Rcpp::NumericVector beta_,
                            Rcpp::IntegerVector numperm_,
-                           Rcpp::IntegerVector seednum_);
+                           Rcpp::IntegerVector seednum_,
+                           Rcpp::IntegerVector twosided_, 
+                           Rcpp::IntegerVector boundedminpval_);
 
 
 double meammd_proj_Rcpp(Rcpp::NumericVector X, 
@@ -82,7 +90,9 @@ Rcpp::List meammd_proj_pval_Rcpp(Rcpp::NumericVector X,
                                  Rcpp::IntegerVector numperm_,
                                  Rcpp::IntegerVector numproj_,
                                  Rcpp::IntegerVector seednum_,
-                                 Rcpp::NumericVector beta_);
+                                 Rcpp::NumericVector beta_,
+                                 Rcpp::IntegerVector twosided_, 
+                                 Rcpp::IntegerVector boundedminpval_);
 
 
 double meammd_dist_pval_Rcpp(Rcpp::NumericVector X, 
@@ -95,7 +105,9 @@ double meammd_dist_pval_Rcpp(Rcpp::NumericVector X,
                              Rcpp::IntegerVector seednum_,
                              Rcpp::NumericVector beta_, 
                              Rcpp::NumericVector pmethod_, 
-                             Rcpp::NumericVector nmethod_);
+                             Rcpp::NumericVector nmethod_,
+                             Rcpp::IntegerVector twosided_, 
+                             Rcpp::IntegerVector boundedminpval_);
 
 Rcpp::List energydist_Rcpp(Rcpp::NumericVector X, 
                            Rcpp::NumericVector Y, 
@@ -112,6 +124,8 @@ Rcpp::List energydist_pval_Rcpp(Rcpp::NumericVector X,
                                 Rcpp::IntegerVector nY_, 
                                 Rcpp::IntegerVector dY_,
                                 Rcpp::IntegerVector numperm_,
-                                Rcpp::IntegerVector seednum_);
+                                Rcpp::IntegerVector seednum_, 
+                                Rcpp::IntegerVector twosided_, 
+                                Rcpp::IntegerVector boundedminpval_);
 
 #endif
